<?php

/**
 * The default template for displaying content
 *
 * Used for both singular and index.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Madrid
 * @since 1.0.0
 */

$madrid_default = madrid_get_default_theme_options();
$madrid_archive_layout = get_theme_mod('madrid_archive_layout', $madrid_default['madrid_archive_layout']);
if ($madrid_archive_layout == 'default' || $madrid_archive_layout == 'lateral' || $madrid_archive_layout == 'masonry') {
    $image_size = 'medium_large';
} else {
    $image_size = 'full';
}
?>
<article id="post-<?php the_ID(); ?>" <?php post_class('theme-article twp-archive-items'); ?>>

    <?php $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), $image_size);
    $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>

    <div class="post-thumbnail">
        <div class="post-thumbnail-content">
            <a href="<?php the_permalink(); ?>">
                <span class="data-bg data-bg-archive" data-background="<?php echo esc_url($featured_image); ?>"></span>
            </a>

            <?php
            $format = get_post_format(get_the_ID()) ?: 'standard';
            $icon = madrid_post_format_icon($format);

            if (!empty($icon)) { ?>
                <div class="post-format-icon"><?php echo madrid_svg_escape($icon); ?></div>
            <?php } ?>

            <div class="image-overlay-content">
                <?php if (class_exists('Booster_Extension_Class') && 'post' === get_post_type()) {
                    madrid_post_view_count();
                    echo do_shortcode('[booster-extension-read-time]');
                } ?>
            </div>
        </div>
    </div>

    <div class="post-content">

        <?php
        if ('post' === get_post_type()) { ?>
            <div class="entry-meta entry-meta-top">
                <?php madrid_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
            </div>
        <?php } ?>

        <header class="entry-header">

            <h2 class="entry-title entry-title-medium">

                <a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>

            </h2>

        </header>

        <?php
        if ($madrid_archive_layout == 'default' || $madrid_archive_layout == 'lateral' || is_sticky()) { ?>

            <div class="entry-excerpt entry-excerpt-muted">
                <?php
                if (has_excerpt()) {

                    the_excerpt();
                } else {

                    echo '<p>' . esc_html(wp_trim_words(get_the_content(), 15, '...')) . '</p>';
                }

                ?>

            </div>

        <?php } ?>

        <div class="entry-footer">
            <div class="entry-meta">
                <?php
                madrid_posted_by();
                ?>
            </div>

            <?php if (class_exists('Booster_Extension_Class') && 'post' === get_post_type()) { ?>
                <div class="post-content-share">
                    <?php echo do_shortcode('[booster-extension-ss layout="layout-2" status="enable"]'); ?>
                </div>
            <?php } ?>
            <?php if ($madrid_archive_layout = 'masonry' && $madrid_archive_layout != 'metro') { ?>
                <div class="entry-read-more"><a href="<?php the_permalink(); ?>" class="theme-button theme-button-border theme-button-small"><?php esc_html_e('Read More', 'madrid'); ?></a></div>
            <?php } ?>

        </div>

    </div>

</article>